@@ -2,10 +2,7 @@ from __future__ import unicode_literals  # pragma: no cover
 import os.path  # pragma nocover
 import sys  # pragma nocover
 
-try:  # pragma nocover
-    import coverage
-except:  # pragma nocover
-    coverage = None
+import coverage # pragma: no cover
 
 __version__ = open(os.path.join(os.path.dirname(__file__), 'VERSION')).read().strip()  # pragma nocover
 if sys.version_info[0] == 2:  # pragma nocover
@@ -15,8 +12,5 @@ if sys.version_info[0] == 2:  # pragma nocover
 
 def pretty_version():  # pragma nocover
     python_version = ".".join([str(x) for x in sys.version_info[0:3]])
-    ver_str = "Green {}".format(__version__)
-    if coverage:
-        ver_str = "{}, Coverage {}".format(ver_str, coverage.__version__)
-    ver_str = "{}, Python {}".format(ver_str, python_version)
+    ver_str = "Green {}, Coverage {}, Python {}".format(__version__, coverage.__version__, python_version)
     return ver_str
